==> ejc-settlementmanage-api-3.0.0-20230113.025707-167-sources.jar: com/ejianc/business/settlementmanage/vo/SettlementCountersignVO.java <==
package com.ejianc.business.settlementmanage.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 总包结算会审会签记录表-主表
 * 
 * @author generator
 * 
 */
public class SettlementCountersignVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编号
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private Long projectId; // 项目id
    private String projectName; // 项目名称
    private Long orgId; // 所属组织id
    private String orgName; // 所属组织名称
    private Long projectDepartmentId; // 项目部id
    private String agentName; // 经办人
    private String contractName; // 合同名称
    private String developer; // 发包人
    private java.math.BigDecimal contractPrice; // 合同造价
    private java.math.BigDecimal actualCost; // 实际成本
    private String structureType; // 结构类型
    private String contractScope; // 承包范围
    private Double constructionArea; // 建筑面积
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")

    private java.util.Date actualCommencementDate; // 实际开工日期
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")

    private java.util.Date actualCompletionDate; // 实际竣工日期
    private java.math.BigDecimal reportedIncome; // 财务已列报收入
    private java.math.BigDecimal received; // 已收款
    private java.math.BigDecimal settlementEstimate; // 结算预估值
    private java.math.BigDecimal adjustmentReport; // 调整后报审值
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")

    private java.util.Date reportDate; // 合同约定结算书报出日期
    private java.math.BigDecimal singleClaimAmount; // 潜在违约及单索赔额
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")

    private java.util.Date reviewDate; // 送审日期
    private String reviewDateStr;
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")

    private java.util.Date latestDeadline; // 审批最迟期限
    private String remarks; // 备注
    private Long agentId; // 经办人id
    private Long agentDepartment; // 经办人部门
    private Long contractId; // 合同id
    private Long developerId; // 发包人id
    private String createTimeShow; // 创建时间文本显示
    private String billStateStr; // 单据状态Str
    private Long originalId;
    /**
     * 单据编号
     */
    public String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")

    public Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */

    public String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 经办人
     */
    public String getAgentName() {
        return agentName;
    }

    /**
     * 经办人
     */
    public void setAgentName(String agentName) {
        this.agentName = agentName;
    }
    /**
     * 合同名称
     */
    public String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    /**
     * 发包人
     */

    public String getDeveloper() {
        return developer;
    }

    /**
     * 发包人
     */

    public void setDeveloper(String developer) {
        this.developer = developer;
    }
    /**
     * 合同造价
     */
    public java.math.BigDecimal getContractPrice() {
        return contractPrice;
    }

    /**
     * 合同造价
     */
    public void setContractPrice(java.math.BigDecimal contractPrice) {
        this.contractPrice = contractPrice;
    }
    /**
     * 实际成本
     */
    public java.math.BigDecimal getActualCost() {
        return actualCost;
    }

    /**
     * 实际成本
     */
    public void setActualCost(java.math.BigDecimal actualCost) {
        this.actualCost = actualCost;
    }
    /**
     * 结构类型
     */
    public String getStructureType() {
        return structureType;
    }

    /**
     * 结构类型
     */
    public void setStructureType(String structureType) {
        this.structureType = structureType;
    }
    /**
     * 承包范围
     */
    public String getContractScope() {
        return contractScope;
    }

    /**
     * 承包范围
     */
    public void setContractScope(String contractScope) {
        this.contractScope = contractScope;
    }
    /**
     * 建筑面积
     */
    public Double getConstructionArea() {
        return constructionArea;
    }

    /**
     * 建筑面积
     */
    public void setConstructionArea(Double constructionArea) {
        this.constructionArea = constructionArea;
    }
    /**
     * 实际开工日期
     */
    public java.util.Date getActualCommencementDate() {
        return actualCommencementDate;
    }

    /**
     * 实际开工日期
     */
    public void setActualCommencementDate(java.util.Date actualCommencementDate) {
        this.actualCommencementDate = actualCommencementDate;
    }
    /**
     * 实际竣工日期
     */
    public java.util.Date getActualCompletionDate() {
        return actualCompletionDate;
    }

    /**
     * 实际竣工日期
     */
    public void setActualCompletionDate(java.util.Date actualCompletionDate) {
        this.actualCompletionDate = actualCompletionDate;
    }
    /**
     * 财务已列报收入
     */
    public java.math.BigDecimal getReportedIncome() {
        return reportedIncome;
    }

    /**
     * 财务已列报收入
     */
    public void setReportedIncome(java.math.BigDecimal reportedIncome) {
        this.reportedIncome = reportedIncome;
    }
    /**
     * 已收款
     */
    public java.math.BigDecimal getReceived() {
        return received;
    }

    /**
     * 已收款
     */
    public void setReceived(java.math.BigDecimal received) {
        this.received = received;
    }
    /**
     * 结算预估值
     */
    public java.math.BigDecimal getSettlementEstimate() {
        return settlementEstimate;
    }

    /**
     * 结算预估值
     */
    public void setSettlementEstimate(java.math.BigDecimal settlementEstimate) {
        this.settlementEstimate = settlementEstimate;
    }
    /**
     * 调整后报审值
     */
    public java.math.BigDecimal getAdjustmentReport() {
        return adjustmentReport;
    }

    /**
     * 调整后报审值
     */
    public void setAdjustmentReport(java.math.BigDecimal adjustmentReport) {
        this.adjustmentReport = adjustmentReport;
    }
    /**
     * 合同约定结算书报出日期
     */
    public java.util.Date getReportDate() {
        return reportDate;
    }

    /**
     * 合同约定结算书报出日期
     */
    public void setReportDate(java.util.Date reportDate) {
        this.reportDate = reportDate;
    }
    /**
     * 潜在违约及单索赔额
     */
    public java.math.BigDecimal getSingleClaimAmount() {
        return singleClaimAmount;
    }

    /**
     * 潜在违约及单索赔额
     */
    public void setSingleClaimAmount(java.math.BigDecimal singleClaimAmount) {
        this.singleClaimAmount = singleClaimAmount;
    }
    /**
     * 送审日期
     */
    public java.util.Date getReviewDate() {
        return reviewDate;
    }

    /**
     * 送审日期
     */
    public void setReviewDate(java.util.Date reviewDate) {
        this.reviewDate = reviewDate;
    }
    /**
     * 审批最迟期限
     */
    public java.util.Date getLatestDeadline() {
        return latestDeadline;
    }

    /**
     * 审批最迟期限
     */
    public void setLatestDeadline(java.util.Date latestDeadline) {
        this.latestDeadline = latestDeadline;
    }
    /**
     * 备注
     */
    public String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }
    /**
     * 经办人id
     */
    @ReferSerialTransfer(referCode="idm-user")

    public Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人id
     */
    @ReferDeserialTransfer

    public void setAgentId(Long agentId) {
        this.agentId = agentId;
    }
    /**
     * 经办人部门
     */
    @ReferSerialTransfer(referCode="idm-dept")

    public Long getAgentDepartment() {
        return agentDepartment;
    }

    /**
     * 经办人部门
     */
    @ReferDeserialTransfer

    public void setAgentDepartment(Long agentDepartment) {
        this.agentDepartment = agentDepartment;
    }
    /**
     * 合同id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-incontract")

    public Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    @ReferDeserialTransfer

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 发包人id
     */
    @ReferSerialTransfer(referCode="support-customer")

    public Long getDeveloperId() {
        return developerId;
    }

    /**
     * 发包人id
     */
    @ReferDeserialTransfer

    public void setDeveloperId(Long developerId) {
        this.developerId = developerId;
    }

    public String getReviewDateStr() {
        return reviewDateStr;
    }

    public void setReviewDateStr(String reviewDateStr) {
        this.reviewDateStr = reviewDateStr;
    }

    public String getCreateTimeShow() {
        return createTimeShow;
    }

    public void setCreateTimeShow(String createTimeShow) {
        this.createTimeShow = createTimeShow;
    }

    public String getBillStateStr() {
        return billStateStr;
    }

    public void setBillStateStr(String billStateStr) {
        this.billStateStr = billStateStr;
    }

    public Long getOriginalId() {
        return originalId;
    }

    public void setOriginalId(Long originalId) {
        this.originalId = originalId;
    }
}

==> ejc-settlementmanage-api-3.0.0-20241227.074412-301-sources.jar: com/ejianc/business/settlementmanage/vo/SettlementCountersignVO.java <==
package com.ejianc.business.settlementmanage.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;


/**
 * 总包结算会审会签记录表-主表
 * 
 * @author generator
 * 
 */
public class SettlementCountersignVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编号
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private Long projectId; // 项目id
    private String projectName; // 项目名称
    private Long orgId; // 所属组织id
    private String orgName; // 所属组织名称
    private Long projectDepartmentId; // 项目部id
    private String agentName; // 经办人
    private String contractName; // 合同名称
    private String developer; // 发包人
    private java.math.BigDecimal contractPrice; // 合同造价
    private java.math.BigDecimal actualCost; // 实际成本
    private String structureType; // 结构类型
    private String contractScope; // 承包范围
    private String constructionArea; // 建筑面积
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")

    private java.util.Date actualCommencementDate; // 实际开工日期
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")

    private java.util.Date actualCompletionDate; // 实际竣工日期
    private java.math.BigDecimal reportedIncome; // 财务已列报收入
    private java.math.BigDecimal received; // 已收款
    private java.math.BigDecimal settlementEstimate; // 结算预估值
    private java.math.BigDecimal adjustmentReport; // 调整后报审值
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")

    private java.util.Date reportDate; // 合同约定结算书报出日期
    private java.math.BigDecimal singleClaimAmount; // 潜在违约及单索赔额
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")

    private java.util.Date reviewDate; // 送审日期
    private String reviewDateStr;
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")

    private java.util.Date latestDeadline; // 审批最迟期限
    private String remarks; // 备注
    private Long agentId; // 经办人id
    private Long agentDepartment; // 经办人部门
    private Long contractId; // 合同id
    private Long developerId; // 发包人id
    private String createTimeShow; // 创建时间文本显示
    private String billStateStr; // 单据状态Str
    private Long originalId;
    private BigDecimal expectSettlementValue; // 预计结算值
    private BigDecimal expectCost; // 预计成本
    private BigDecimal expectProfit; // 预计利润额
    private BigDecimal expectProfitRate; // 预计利润率%
    private BigDecimal targetResponsibilityMargin; // 目标责任书利润率

    public BigDecimal getExpectSettlementValue() {
        return expectSettlementValue;
    }

    public void setExpectSettlementValue(BigDecimal expectSettlementValue) {
        this.expectSettlementValue = expectSettlementValue;
    }

    public BigDecimal getExpectCost() {
        return expectCost;
    }

    public void setExpectCost(BigDecimal expectCost) {
        this.expectCost = expectCost;
    }

    public BigDecimal getExpectProfit() {
        return expectProfit;
    }

    public void setExpectProfit(BigDecimal expectProfit) {
        this.expectProfit = expectProfit;
    }

    public BigDecimal getExpectProfitRate() {
        return expectProfitRate;
    }

    public void setExpectProfitRate(BigDecimal expectProfitRate) {
        this.expectProfitRate = expectProfitRate;
    }

    public BigDecimal getTargetResponsibilityMargin() {
        return targetResponsibilityMargin;
    }

    public void setTargetResponsibilityMargin(BigDecimal targetResponsibilityMargin) {
        this.targetResponsibilityMargin = targetResponsibilityMargin;
    }

    /**
     * 单据编号
     */
    public String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")

    public Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */

    public String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 经办人
     */
    public String getAgentName() {
        return agentName;
    }

    /**
     * 经办人
     */
    public void setAgentName(String agentName) {
        this.agentName = agentName;
    }
    /**
     * 合同名称
     */
    public String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    /**
     * 发包人
     */

    public String getDeveloper() {
        return developer;
    }

    /**
     * 发包人
     */

    public void setDeveloper(String developer) {
        this.developer = developer;
    }
    /**
     * 合同造价
     */
    public java.math.BigDecimal getContractPrice() {
        return contractPrice;
    }

    /**
     * 合同造价
     */
    public void setContractPrice(java.math.BigDecimal contractPrice) {
        this.contractPrice = contractPrice;
    }
    /**
     * 实际成本
     */
    public java.math.BigDecimal getActualCost() {
        return actualCost;
    }

    /**
     * 实际成本
     */
    public void setActualCost(java.math.BigDecimal actualCost) {
        this.actualCost = actualCost;
    }
    /**
     * 结构类型
     */
    public String getStructureType() {
        return structureType;
    }

    /**
     * 结构类型
     */
    public void setStructureType(String structureType) {
        this.structureType = structureType;
    }
    /**
     * 承包范围
     */
    public String getContractScope() {
        return contractScope;
    }

    /**
     * 承包范围
     */
    public void setContractScope(String contractScope) {
        this.contractScope = contractScope;
    }

    public String getConstructionArea() {
        return constructionArea;
    }

    public void setConstructionArea(String constructionArea) {
        this.constructionArea = constructionArea;
    }

    /**
     * 实际开工日期
     */
    public java.util.Date getActualCommencementDate() {
        return actualCommencementDate;
    }

    /**
     * 实际开工日期
     */
    public void setActualCommencementDate(java.util.Date actualCommencementDate) {
        this.actualCommencementDate = actualCommencementDate;
    }
    /**
     * 实际竣工日期
     */
    public java.util.Date getActualCompletionDate() {
        return actualCompletionDate;
    }

    /**
     * 实际竣工日期
     */
    public void setActualCompletionDate(java.util.Date actualCompletionDate) {
        this.actualCompletionDate = actualCompletionDate;
    }
    /**
     * 财务已列报收入
     */
    public java.math.BigDecimal getReportedIncome() {
        return reportedIncome;
    }

    /**
     * 财务已列报收入
     */
    public void setReportedIncome(java.math.BigDecimal reportedIncome) {
        this.reportedIncome = reportedIncome;
    }
    /**
     * 已收款
     */
    public java.math.BigDecimal getReceived() {
        return received;
    }

    /**
     * 已收款
     */
    public void setReceived(java.math.BigDecimal received) {
        this.received = received;
    }
    /**
     * 结算预估值
     */
    public java.math.BigDecimal getSettlementEstimate() {
        return settlementEstimate;
    }

    /**
     * 结算预估值
     */
    public void setSettlementEstimate(java.math.BigDecimal settlementEstimate) {
        this.settlementEstimate = settlementEstimate;
    }
    /**
     * 调整后报审值
     */
    public java.math.BigDecimal getAdjustmentReport() {
        return adjustmentReport;
    }

    /**
     * 调整后报审值
     */
    public void setAdjustmentReport(java.math.BigDecimal adjustmentReport) {
        this.adjustmentReport = adjustmentReport;
    }
    /**
     * 合同约定结算书报出日期
     */
    public java.util.Date getReportDate() {
        return reportDate;
    }

    /**
     * 合同约定结算书报出日期
     */
    public void setReportDate(java.util.Date reportDate) {
        this.reportDate = reportDate;
    }
    /**
     * 潜在违约及单索赔额
     */
    public java.math.BigDecimal getSingleClaimAmount() {
        return singleClaimAmount;
    }

    /**
     * 潜在违约及单索赔额
     */
    public void setSingleClaimAmount(java.math.BigDecimal singleClaimAmount) {
        this.singleClaimAmount = singleClaimAmount;
    }
    /**
     * 送审日期
     */
    public java.util.Date getReviewDate() {
        return reviewDate;
    }

    /**
     * 送审日期
     */
    public void setReviewDate(java.util.Date reviewDate) {
        this.reviewDate = reviewDate;
    }
    /**
     * 审批最迟期限
     */
    public java.util.Date getLatestDeadline() {
        return latestDeadline;
    }

    /**
     * 审批最迟期限
     */
    public void setLatestDeadline(java.util.Date latestDeadline) {
        this.latestDeadline = latestDeadline;
    }
    /**
     * 备注
     */
    public String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }
    /**
     * 经办人id
     */
    @ReferSerialTransfer(referCode="idm-user")

    public Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人id
     */
    @ReferDeserialTransfer

    public void setAgentId(Long agentId) {
        this.agentId = agentId;
    }
    /**
     * 经办人部门
     */
    @ReferSerialTransfer(referCode="idm-dept")

    public Long getAgentDepartment() {
        return agentDepartment;
    }

    /**
     * 经办人部门
     */
    @ReferDeserialTransfer

    public void setAgentDepartment(Long agentDepartment) {
        this.agentDepartment = agentDepartment;
    }
    /**
     * 合同id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-incontract")

    public Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    @ReferDeserialTransfer

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 发包人id
     */
    @ReferSerialTransfer(referCode="support-customer")

    public Long getDeveloperId() {
        return developerId;
    }

    /**
     * 发包人id
     */
    @ReferDeserialTransfer

    public void setDeveloperId(Long developerId) {
        this.developerId = developerId;
    }

    public String getReviewDateStr() {
        return reviewDateStr;
    }

    public void setReviewDateStr(String reviewDateStr) {
        this.reviewDateStr = reviewDateStr;
    }

    public String getCreateTimeShow() {
        return createTimeShow;
    }

    public void setCreateTimeShow(String createTimeShow) {
        this.createTimeShow = createTimeShow;
    }

    public String getBillStateStr() {
        return billStateStr;
    }

    public void setBillStateStr(String billStateStr) {
        this.billStateStr = billStateStr;
    }

    public Long getOriginalId() {
        return originalId;
    }

    public void setOriginalId(Long originalId) {
        this.originalId = originalId;
    }
}
